@@ -76,6 +76,7 @@
 #'                U = 1,
 #'                solver = c("alabama", "cccp", "cccp2", "slsqp"),
 #'                give_X = TRUE,
+#'                n_attempts_max = 5,
 #'                returnqp = FALSE,
 #'                ...)
 #'
@@ -106,6 +107,8 @@
 #' the evaluated DMU) for the solver, except for "cccp". If it is \code{FALSE},
 #' the initial vector is given internally by the solver and it is usually
 #' randomly generated.
+#' @param n_attempts_max A value with the maximum number of attempts if the solver
+#' does not converge. Each attempt uses a different initial vector.
 #' @param returnqp Logical. If it is \code{TRUE}, it returns the quadratic
 #' problems (objective function and constraints).
 #' @param ... Other parameters, like the initial vector \code{X}, to be passed
@@ -156,6 +159,7 @@ modelstoch_additive <-
            U = 1,
            solver = c("alabama", "cccp", "cccp2", "slsqp"),
            give_X = TRUE,
+           n_attempts_max = 5,
            returnqp = FALSE,
            ...) {
 
@@ -411,16 +415,27 @@ modelstoch_additive <-
 
       } else {
 
-        # Initial vector
-        if ((ii %in% dmu_ref) && give_X) {
-          Xini <- rep(0, nvar)
-          Xini[which(dmu_ref == ii)] <- 1
-          names(Xini) <- namevar
-        } else {
-          Xini <- NULL
-        }
+        n_attempts <- 1
 
-        res <- solvecop(op = mycop, solver = solver, quiet = TRUE, X = Xini, ...)
+        while (n_attempts <= n_attempts_max) {
+
+          # Initial vector
+          if ((n_attempts == 1) && give_X && (ii %in% dmu_ref)) {
+            Xini <- rep(0, nvar)
+            Xini[which(dmu_ref == ii)] <- 1
+            names(Xini) <- namevar
+          } else {
+            Xini <- NULL
+          }
+
+          res <- solvecop(op = mycop, solver = solver, quiet = TRUE, X = Xini, ...)
+
+          if (res$status == "successful convergence") {
+            n_attempts <- n_attempts_max
+          }
+          n_attempts <- n_attempts + 1
+
+        }
 
         if (res$status == "successful convergence") {
 
